package sun.text.normalizer;

import java.text.CharacterIterator;

public class CharacterIteratorWrapper extends UCharacterIterator
{
    private CharacterIterator iterator;
    
    public CharacterIteratorWrapper(CharacterIterator iterator) {
        if (iterator == null) {
            throw new IllegalArgumentException();
        }
        this.iterator = iterator;
        return;
    }
    
    @Override
    public int current() {
        int current = this.iterator.current();
        if (current == '\uffff') {
            return -1;
        }
        return current;
    }
    
    @Override
    public int getLength() {
        return this.iterator.getEndIndex() - this.iterator.getBeginIndex();
    }
    
    @Override
    public int getIndex() {
        return this.iterator.getIndex();
    }
    
    @Override
    public int next() {
        int current = this.iterator.current();
        this.iterator.next();
        if (current == '\uffff') {
            return -1;
        }
        return current;
    }
    
    @Override
    public int previous() {
        int previous = this.iterator.previous();
        if (previous == '\uffff') {
            return -1;
        }
        return previous;
    }
    
    @Override
    public void setIndex(int index) {
        this.iterator.setIndex(index);
    }
    
    @Override
    public int getText(char[] array, int n) {
        int i = this.iterator.getEndIndex() - this.iterator.getBeginIndex();
        int index = this.iterator.getIndex();
        if (n < 0 || n + i > array.length) {
            throw new IndexOutOfBoundsException(Integer.toString(i));
        }
        for (int j = this.iterator.first(); j != '\uffff'; j = this.iterator.next()) {
            array[n++] = j;
        }
        this.iterator.setIndex(index);
        return i;
    }
    
    @Override
    public Object clone() {
        try {
            CharacterIteratorWrapper characterIteratorWrapper = (CharacterIteratorWrapper)super.clone();
            characterIteratorWrapper.iterator = (CharacterIterator)this.iterator.clone();
            return characterIteratorWrapper;
        }
        catch (CloneNotSupportedException ex) {
            return null;
        }
    }
}
